//Source file: TerminalCapabilitiesError.java
//Date: June 2004
//Terminal Capability Interfaces and Data Types for 3GPP TS 29.198-07 V5.6.0

package org.csapi.jr.se.termcap;

/**
 * Defines an error that is reported by the Terminal Capabilities SCF.
 *
 */
public final class TerminalCapabilitiesError implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static TerminalCapabilitiesError[] _array = new TerminalCapabilitiesError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private TerminalCapabilitiesError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined.
     */
    public static final int _TERMCAP_ERROR_UNDEFINED =  0;

    /**
     * Undefined.
     */
    public static final TerminalCapabilitiesError TERMCAP_ERROR_UNDEFINED = new TerminalCapabilitiesError(_TERMCAP_ERROR_UNDEFINED);

    /**
     * The request can not be handled because the terminal id specified is not valid.
     */
    public static final int _TERMCAP_INVALID_TERMINALID =  1;

    /**
     * The request can not be handled because the terminal id specified is not valid.
     */
    public static final TerminalCapabilitiesError TERMCAP_INVALID_TERMINALID = new TerminalCapabilitiesError(_TERMCAP_INVALID_TERMINALID);

    /**
     * System failure.
The request cannot be handled because of a general problem in the terminal capabilities service or the underlying network.
     */
    public static final int _TERMCAP_SYSTEM_FAILURE =  2;

    /**
     * System failure.
The request cannot be handled because of a general problem in the terminal capabilities service or the underlying network.
     */
    public static final TerminalCapabilitiesError TERMCAP_SYSTEM_FAILURE = new TerminalCapabilitiesError(_TERMCAP_SYSTEM_FAILURE);

    /**
     * The terminal capability information is not available.
     */
    public static final int _TERMCAP_INFO_UNAVAILABLE =  3;

    /**
     * The terminal capability information is not available.
     */
    public static final TerminalCapabilitiesError TERMCAP_INFO_UNAVAILABLE = new TerminalCapabilitiesError(_TERMCAP_INFO_UNAVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved TerminalCapabilitiesError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the TerminalCapabilitiesError object
     */
    public String getValueText() {
        switch (_value) {
            case _TERMCAP_ERROR_UNDEFINED:
                return "TERMCAP_ERROR_UNDEFINED";
            case _TERMCAP_INVALID_TERMINALID:
                return "TERMCAP_INVALID_TERMINALID";
            case _TERMCAP_SYSTEM_FAILURE:
                return "TERMCAP_SYSTEM_FAILURE";
            case _TERMCAP_INFO_UNAVAILABLE:
                return "TERMCAP_INFO_UNAVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static TerminalCapabilitiesError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TerminalCapabilitiesError)) {
            return false;
        }
        TerminalCapabilitiesError terminalCapabilitiesError = (TerminalCapabilitiesError) o; 
        if(!(this.getValue() == terminalCapabilitiesError.getValue())) {
            return false;
        }
        if (this.hashCode() != terminalCapabilitiesError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TerminalCapabilitiesError

