//Source file: TypeTerminalCapabilities.java
//Date: June 2004
//Terminal Capability Interfaces and Data Types for 3GPP TS 29.198-07 V5.6.0

package org.csapi.jr.se.termcap;

/**
 * This data type is a Sequence of Data Elements that describes the terminal capabilities.
 * 
 */
public final class TypeTerminalCapabilities implements java.io.Serializable {

    private String terminalCapabilities;
    private boolean statusCode;

    /**
     * Creates a new TerminalCapabilities instance.
     */
    public TypeTerminalCapabilities () {}

    /**
     * Creates a new TerminalCapabilities instance.
     * @param _terminalCapabilities   Specifies the latest available capabilities of the user's terminal.
This information, if available, is returned as CC/PP headers as specified in W3C (see [6] in ES 202 915-1) and adopted in the WAP UAProf specification (see [9] in ES 202 915-1). It contains URLs; terminal attributes and values, in RDF format; or a combination of both.
     * @param _statusCode   Indicates whether or not the TerminalCapabilities are available.
     */
    public TypeTerminalCapabilities (String _terminalCapabilities, boolean _statusCode) {

        this.terminalCapabilities = _terminalCapabilities;
        this.statusCode = _statusCode;
    }

    /**
     * This method returns a terminalCapabilities.
     * 
     * @return a String value
     */
    public String getTerminalCapabilities() {
        return terminalCapabilities;
    }

    /**
     * This method returns a statusCode.
     * 
     * @return a boolean value
     */
    public boolean getStatusCode() {
        return statusCode;
    }


    /**
     * This method sets a terminalCapabilities.
     */ 
    public void setTerminalCapabilities(String terminalCapabilities) {
        this.terminalCapabilities = terminalCapabilities;
    }

    /**
     * This method sets a statusCode.
     */ 
    public void setStatusCode(boolean statusCode) {
        this.statusCode = statusCode;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof TypeTerminalCapabilities)) {
            return false;
        } 
        TypeTerminalCapabilities terminalCapabilities = (TypeTerminalCapabilities) o;
        if(!(this.statusCode == terminalCapabilities.statusCode)) {
            return false;
        }
        if ((this.terminalCapabilities != null) && (terminalCapabilities.terminalCapabilities != null)) {
            if(!(this.terminalCapabilities.equals(terminalCapabilities.terminalCapabilities)))  {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // TypeTerminalCapabilities

